% This script plots the estimated and real biases, the position, speed,
% clock bias, clock drift and state vector RMSEs, the evolution of the
% trajectory and the evolution of the clock bias
%
% Julien LESOUPLE 13 sep 2018

figure
hold on
plot(mp_bias_th(1:n,:)',':')
ax = gca;
ax.ColorOrderIndex = 1;
plot(mt_hat(1:n,:)')
hold off
title('MP PR bias (dashed) and estimated (continuous)')
box on
grid on

figure
hold on
plot(mp_bias_th(n+1:2*n,:)',':')
ax = gca;
ax.ColorOrderIndex = 1;
plot(mt_hat(n+1:2*n,:)')
hold off
title('MP PR rate bias (dashed) and estimated (continuous)')
box on
grid on

figure
subplot(221)
hold on
plot(sum((Xt(1:2:5,:)-X_EKF(1:2:5,:)).^2,1))
plot(sum((Xt(1:2:5,:)-X_sparse(1:2:5,:)).^2,1))
hold off
legend('EKF','Sparse')
title('Position MSE')
box on
grid on

subplot(222)
hold on
plot(sum((Xt(2:2:6,:)-X_EKF(2:2:6,:)).^2,1))
plot(sum((Xt(2:2:6,:)-X_sparse(2:2:6,:)).^2,1))
hold off
legend('EKF','Sparse')
title('Speed MSE')
box on
grid on

subplot(223)
hold on
plot(sum((Xt(7,:)-X_EKF(7,:)).^2,1))
plot(sum((Xt(7,:)-X_sparse(7,:)).^2,1))
hold off
legend('EKF','Sparse')
title('Clock bias MSE')
box on
grid on

subplot(224)
hold on
plot(sum((Xt(8,:)-X_EKF(8,:)).^2,1))
plot(sum((Xt(8,:)-X_sparse(8,:)).^2,1))
hold off
legend('EKF','Sparse')
title('Clock drift MSE')
box on
grid on

figure
hold on
plot(sum((Xt-X_EKF).^2,1))
plot(sum((Xt-X_sparse).^2,1))
hold off
legend('EKF','Sparse')
title('State vector MSE')
box on
grid on


% Visualize X,Y trajectory
figure
hold on
plot(Xt(1,:),Xt(3,:))
plot(X_EKF(1,:),X_EKF(3,:))
plot(X_sparse(1,:),X_sparse(3,:))
hold off
box on
title('Trajectory in 2D')
legend('Reference','EKF','Sparse')
xlabel('X')
ylabel('Y')
set(gca,'YTickLabel',[])
set(gca,'XTickLabel',[])

figure
hold on
plot(Xt(7,:))
plot(X_EKF(7,:))
plot(X_sparse(7,:))
hold off
grid on
box on
legend('Reference','EKF','Sparse')
title('Receiver clock bias')